#
# spec file for package python-oslo.serialization
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.serialization
Name:           python-oslo.serialization
Version:        2.13.0
Release:        1.2
Summary:        OpenStack serialization library
License:        Apache-2.0
Group:          Development/Languages
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-ipaddress >= 1.0.7
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-msgpack-python >= 0.4.0
BuildRequires:  python-netaddr >= 0.7.12
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
Requires:       python-msgpack-python >= 0.4.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-pytz >= 2013.6
Requires:       python-six >= 1.9.0
BuildArch:      noarch

%description
The oslo.serialization library provides support for representing objects
in transmittable and storable formats, such as Base64, JSON and MessagePack.

%package doc
Summary:        Documentation for OpenStack serialization library
Group:          Development/Languages
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
The oslo.serialization library provides support for representing objects
in transmittable and storable formats, such as Base64, JSON and MessagePack.
This package contains the documentation.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

# generate html docs
%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
%{__python2} setup.py test

%files
%license LICENSE
%doc README.rst AUTHORS ChangeLog
%{python2_sitelib}/oslo_serialization
%{python2_sitelib}/*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Sep  2 2016 tbechtold@suse.com
- update to version 2.13.0
  * Fix serialization of binary strings in Python3
  * Drop H803 in flake8 ignore list
* Wed Aug 10 2016 tbechtold@suse.com
- update to 2.12.0:
  * Updated from global requirements
  * Fix parameters of assertEqual are misplaced
  * Add Python 3.5 classifier and venv
  * Use {} instead of dict()
  * Replace TypeError by ValueError in msgpackutils
  * Support serializing ipaddress objs with jsonutils
* Sun Jun 19 2016 dmueller@suse.com
- update to 2.7.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * [Trivial] Remove executable privilege of doc/source/conf.py
  * Drop babel as requirement since its not used
  * Updated from global requirements
  * Unified and simplified API for all serializers
  * Make msgpack registries copyable (and add __contains__)
  * msgpack: fix datetime serialization
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- update to 2.4.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Remove fallback to simplejson in jsonutils
  * Remove iso8601 dependency
  * Updated from global requirements
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * msgpackutils: drop Python 2.6 support
  * Updated from global requirements
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Fix bug track URL
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
- Switch to .spec from rpm-packaging upstream project
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 1.11.0
  * Fix coverage configuration and execution
- update to 1.10.0:
  * Add utilities for base64
  * Also check for the existence of `items` in to_primitive()
  * Move 'history' -> release notes section
  * Add jsonutils.dump_as_bytes() function for py3
  * Change ignore-errors to ignore_errors
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.9.0:
  * Updated from global requirements
  * Drop stale test - test_jsonutils
  * Stop using deprecated oslo_utils.timeutils.strtime
  * Add tox target to find missing requirements
  * Remove oslo namespace package
  * Do not use oslo namespace for oslo.i18n lib
  * Switch badges from 'pypip.in' to 'shields.io'
- Adjust Requires according to requirements.txt
* Mon Aug 10 2015 seife+obs@b1-systems.com
- fix spelling of python-Sphinx BuildRequires
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
- Add -doc package
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Mon Jun  8 2015 tbechtold@suse.com
- update to 1.6.0:
  * Revert "jsonutils: replace strtime(
  * jsonutils: encode dict keys
  * jsonutils: simplify simple value handling
  * jsonutils: replace strtime() usage with isoformat()
  * Advertise support for Python3.4 / Remove support for Python 3.3
  * Do not sync run_cross_tests.sh
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * Fixes wrong folder for listing tests
  * Expose base msgpack exceptions so users don't need to import
  * Uncap library requirements for liberty
  * More docstring cleanups/tweaks
  * Add docstring(s) to handler registry(s)
  * Add pypi download + version badges
  * Cleanup README.rst and setup.cfg
  * Make the msgpackutils handlers more extendable
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Wed Jun  3 2015 dmueller@suse.com
- remove hacking dep
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.4.0:
  * Updated from global requirements
- update Requires
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 1.3.0:
  * add dependency warning to requirements.txt
  * Correctly load and dump items with datetime.date(s)
  * Avoid using strtime for serializing datetimes
  * jsonutils: add set() tests and simplify recursive code
  * jsonutils: support UUID encoding
  * Use default in dumps()
  * Updated from global requirements
  * Update Oslo imports to remove namespace package
  * Add a messagepack utils helper module
  * Bump to hacking 0.10
  * Updated from global requirements
  * fix bug tracker link in README.rst
- Add python-pytz and python-msgpack-python as Requires
- Remove SLES11 compat
* Thu Jan 15 2015 tbechtold@suse.com
- update to 1.2.0:
  * Move files out of the namespace package
  * Activate pep8 check that _ is imported
  * Updated from global requirements
  * Workflow documentation is now in infra-manual
- Add python_requires to _service
* Thu Jan  8 2015 dmueller@suse.com
- update to 1.1.0:
  * Add pbr to installation requirements
  * Updated from global requirements
  * Fix pep8, docs, requirements issues in jsonutils and tests
  * Remove extraneous vim editor configuration comments
  * Support building wheels (PEP-427)
  * Fix coverage testing
  * Updated from global requirements
  * Support 'built-in' datetime module
* Fri Oct 17 2014 dmueller@suse.com
- add LICENSE
* Sun Sep 21 2014 tbechtold@suse.com
- Update to version 1.0.0:
  * Updated from global requirements
- Adjust Requires version of python-oslo.utils according to
  requirements.txt
* Tue Sep  9 2014 tbechtold@suse.com
- Initial version
